<?php

/**
 * Contains Entitlements.
 */

/**
 * Defines a set of static Entitlements functions.
 */
class Entitlements {

  /**
   * @param $account
   *   (optional) The account to check, if not given use currently logged in user.
   * @param $provider
   *   The name of a provider.
   * @param $realm
   *   The name of a provider realm.
   * @param $name
   *   The name of an entitlement.
   *
   * @return boolean
   *   TRUE if the current user has the requested entitlement.
   */
  public static function hasEntitlement($account, $provider, $realm, $name) {
    return db_select('entitlements', 'e')
      ->fields('e')
      ->condition('uid', $account->uid)
      ->condition('provider', $provider)
      ->condition('realm', $realm)
      ->condition('name', $name)
      ->execute()
      ->fetch() != FALSE;
  }

  /**
   * Get a list of entitlements for an account.
   *
   * @param $account
   *   (optional) The account to check, if not given use currently logged in user.
   *
   * @return
   *   An array of account entitlements.
   */
  public static function getEntitlements($account = NULL) {
    global $user;

    if (!isset($account)) {
      $account = $user;
    }

    return db_select('entitlements', 'e')
      ->fields('e', array('provider', 'realm', 'name'))
      ->condition('uid', $account->uid)
      ->execute()
      ->fetchAll();
  }

  /**
   * Get information about a single provider.
   *
   * @param $provider
   *   The name of a provider.
   *
   * @return
   *   An array of information for a single provider.
   */
  public static function getProvider($provider) {
    $providers = drupal_static(__FUNCTION__);
    if (!isset($providers)) {
      $providers = array();
    }
    if (!array_key_exists($provider, $providers)) {
      $provider_info = self::getProviderInfo();
      $provider_class = $provider_info[$provider]['class'];
      $providers[$provider] = new $provider_class();
    }
    return $providers[$provider];
  }

  /**
   * List all available providers.
   *
   * @return
   *   An array of available entitlements providers.
   */
  public static function getProviderInfo() {
    $providers = &drupal_static(__FUNCTION__);
    if (!isset($providers)) {
      $providers = module_invoke_all('entitlements_provider_info');
    }
    return $providers;
  }

  /**
   * List all available consumers.
   *
   * @return
   *   An array of available entitlements consumers.
   */
  public static function getConsumerInfo() {
    $consumer = &drupal_static(__FUNCTION__);
    if (!isset($consumer)) {
      $consumer = module_invoke_all('entitlements_consumer_info');
    }
    return $consumer;
  }

}
